@@ -139,25 +139,20 @@ def limited(items, request, max_limit=CONF.osapi_max_limit):
 def remove_version_from_href(href):
     """Removes the first api version from the href.
 
-    Given: 'http://manila.example.com/v1.1/123'
-    Returns: 'http://manila.example.com/123'
+    Given: 'http://www.manila.com/v1.1/123'
+    Returns: 'http://www.manila.com/123'
 
     Given: 'http://www.manila.com/v1.1'
     Returns: 'http://www.manila.com'
 
-    Given: 'http://manila.example.com/share/v1.1/123'
-    Returns: 'http://manila.example.com/share/123'
-
     """
     parsed_url = parse.urlsplit(href)
-    url_parts = parsed_url.path.split('/')
+    url_parts = parsed_url.path.split('/', 2)
 
     # NOTE: this should match vX.X or vX
     expression = re.compile(r'^v([0-9]+|[0-9]+\.[0-9]+)(/.*|$)')
-    for x in range(len(url_parts)):
-        if expression.match(url_parts[x]):
-            del url_parts[x]
-            break
+    if expression.match(url_parts[1]):
+        del url_parts[1]
 
     new_path = '/'.join(url_parts)
 
@@ -314,14 +309,28 @@ def validate_common_name(access):
         exc_str = _('Invalid CN (common name). Must be 1-64 chars long.')
         raise webob.exc.HTTPBadRequest(explanation=exc_str)
 
+'''
+for the reference specification for AD usernames, reference below links:
+
+  1:https://msdn.microsoft.com/en-us/library/bb726984.aspx
+  2:https://technet.microsoft.com/en-us/library/cc733146.aspx
+'''
+
 
 def validate_username(access):
-    valid_username_re = '[\w\$\.\-_\`;\'\{\}\[\]\\\\]{4,255}$'
+    sole_periods_spaces_re = '[\s|\.]+$'
+    valid_username_re = '.[^\"\/\\\[\]\:\;\|\=\,\+\*\?\<\>]{3,254}$'
     username = access
+
+    if re.match(sole_periods_spaces_re, username):
+        exc_str = ('Invalid user or group name,cannot consist solely '
+                   'of periods or spaces.')
+        raise webob.exc.HTTPBadRequest(explanation=exc_str)
+
     if not re.match(valid_username_re, username):
         exc_str = ('Invalid user or group name. Must be 4-255 characters '
                    'and consist of alphanumeric characters and '
-                   'special characters $]{.-_\'`;}[\\')
+                   'exclude special characters "/\[]:;|=,+*?<>')
         raise webob.exc.HTTPBadRequest(explanation=exc_str)
 
 
