@@ -22,6 +22,7 @@ from oslo_log import log
 from oslo_serialization import jsonutils
 from oslo_utils import strutils
 import six
+from six.moves import http_client
 import webob
 import webob.exc
 
@@ -53,7 +54,6 @@ API_VERSION_REQUEST_HEADER = 'X-OpenStack-Manila-API-Version'
 EXPERIMENTAL_API_REQUEST_HEADER = 'X-OpenStack-Manila-API-Experimental'
 
 V1_SCRIPT_NAME = '/v1'
-V2_SCRIPT_NAME = '/v2'
 
 
 class Request(webob.Request):
@@ -219,11 +219,10 @@ class Request(webob.Request):
         Microversions starts with /v2, so if a client sends a /v1 URL, then
         ignore the headers and request 1.0 APIs.
         """
-        if not self.script_name or not (V1_SCRIPT_NAME in self.script_name or
-                                        V2_SCRIPT_NAME in self.script_name):
-            # The request is on the base URL without a major version specified
+
+        if not self.script_name:
             self.api_version_request = api_version.APIVersionRequest()
-        elif V1_SCRIPT_NAME in self.script_name:
+        elif self.script_name == V1_SCRIPT_NAME:
             self.api_version_request = api_version.APIVersionRequest('1.0')
         else:
             if API_VERSION_REQUEST_HEADER in self.headers:
@@ -865,7 +864,7 @@ class Resource(wsgi.Application):
             for hdr, val in response.headers.items():
                 val = utils.convert_str(val)
                 response.headers[hdr] = val
-            _set_request_id_header(request, response.headers)
+
             if not request.api_version_request.is_null():
                 response.headers[API_VERSION_REQUEST_HEADER] = (
                     request.api_version_request.get_string())
@@ -1243,7 +1242,7 @@ class AdminActionsMixin(object):
             self._update(context, id, update)
         except exception.NotFound as e:
             raise webob.exc.HTTPNotFound(six.text_type(e))
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     @Controller.authorize('force_delete')
     def _force_delete(self, req, id, body):
@@ -1254,7 +1253,7 @@ class AdminActionsMixin(object):
         except exception.NotFound as e:
             raise webob.exc.HTTPNotFound(six.text_type(e))
         self._delete(context, resource, force=True)
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
 
 class Fault(webob.exc.HTTPException):
