@@ -16,6 +16,7 @@
 """The security service api."""
 
 from oslo_log import log
+from six.moves import http_client
 import webob
 from webob import exc
 
@@ -65,14 +66,14 @@ class SecurityServiceController(wsgi.Controller):
         share_nets = db.share_network_get_all_by_security_service(
             context, id)
         if share_nets:
-            # Cannot delete security service
-            # if it is assigned to share networks
-            raise exc.HTTPForbidden()
+            msg = _("Cannot delete security service. It is "
+                    "assigned to share network(s)")
+            raise exc.HTTPForbidden(explanation=msg)
         policy.check_policy(context, RESOURCE_NAME,
                             'delete', security_service)
         db.security_service_delete(context, id)
 
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def index(self, req):
         """Returns a summary list of security services."""
