@@ -21,6 +21,7 @@ from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 import six
+from six.moves import http_client
 import webob
 from webob import exc
 
@@ -97,7 +98,7 @@ class ShareMixin(object):
         except exception.Conflict as e:
             raise exc.HTTPConflict(explanation=six.text_type(e))
 
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def index(self, req):
         """Returns a summary list of shares."""
@@ -123,12 +124,12 @@ class ShareMixin(object):
         """Returns a list of shares, transformed through view builder."""
         context = req.environ['manila.context']
 
-        common._validate_pagination_query(req)
-
         search_opts = {}
         search_opts.update(req.GET)
 
         # Remove keys that are not related to share attrs
+        search_opts.pop('limit', None)
+        search_opts.pop('offset', None)
         sort_key = search_opts.pop('sort_key', 'created_at')
         sort_dir = search_opts.pop('sort_dir', 'desc')
 
@@ -173,10 +174,14 @@ class ShareMixin(object):
         if show_count:
             total_count = len(shares)
 
+        limited_list = common.limited(shares, req)
+
         if is_detail:
-            shares = self._view_builder.detail_list(req, shares, total_count)
+            shares = self._view_builder.detail_list(req, limited_list,
+                                                    total_count)
         else:
-            shares = self._view_builder.summary_list(req, shares, total_count)
+            shares = self._view_builder.summary_list(req, limited_list,
+                                                     total_count)
         return shares
 
     def _get_share_search_options(self):
@@ -191,7 +196,7 @@ class ShareMixin(object):
             'is_public', 'metadata', 'extra_specs', 'sort_key', 'sort_dir',
             'share_group_id', 'share_group_snapshot_id', 'export_location_id',
             'export_location_path', 'display_name~', 'display_description~',
-            'display_description', 'limit', 'offset'
+            'display_description'
         )
 
     def update(self, req, id, body):
@@ -387,10 +392,13 @@ class ShareMixin(object):
 
     @wsgi.Controller.authorize('allow_access')
     def _allow_access(self, req, id, body, enable_ceph=False,
-                      allow_on_error_status=False, enable_ipv6=False):
+                      allow_on_error_status=False, enable_ipv6=False,
+                      enable_metadata=False):
         """Add share access rule."""
         context = req.environ['manila.context']
         access_data = body.get('allow_access', body.get('os-allow_access'))
+        if not enable_metadata:
+            access_data.pop('metadata', None)
         share = self.share_api.get(context, id)
 
         if (not allow_on_error_status and
@@ -414,10 +422,16 @@ class ShareMixin(object):
         try:
             access = self.share_api.allow_access(
                 context, share, access_type, access_to,
-                access_data.get('access_level'))
+                access_data.get('access_level'), access_data.get('metadata'))
         except exception.ShareAccessExists as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
 
+        except exception.InvalidMetadata as error:
+            raise exc.HTTPBadRequest(explanation=error.msg)
+
+        except exception.InvalidMetadataSize as error:
+            raise exc.HTTPBadRequest(explanation=error.msg)
+
         return self._access_view_builder.view(req, access)
 
     @wsgi.Controller.authorize('deny_access')
@@ -436,7 +450,7 @@ class ShareMixin(object):
         except exception.NotFound as error:
             raise webob.exc.HTTPNotFound(explanation=six.text_type(error))
         self.share_api.deny_access(context, share, access)
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def _access_list(self, req, id, body):
         """List share access rules."""
@@ -460,7 +474,7 @@ class ShareMixin(object):
         except exception.ShareSizeExceedsAvailableQuota as e:
             raise webob.exc.HTTPForbidden(explanation=six.text_type(e))
 
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def _shrink(self, req, id, body):
         """Shrink size of a share."""
@@ -473,7 +487,7 @@ class ShareMixin(object):
         except (exception.InvalidInput, exception.InvalidShare) as e:
             raise webob.exc.HTTPBadRequest(explanation=six.text_type(e))
 
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def _get_valid_resize_parameters(self, context, id, body, action):
         try:
@@ -497,7 +511,7 @@ class ShareController(wsgi.Controller, ShareMixin, wsgi.AdminActionsMixin):
     _view_builder_class = share_views.ViewBuilder
 
     def __init__(self):
-        super(self.__class__, self).__init__()
+        super(ShareController, self).__init__()
         self.share_api = share.API()
         self._access_view_builder = share_access_views.ViewBuilder()
 
