@@ -280,10 +280,11 @@ def quota_destroy_all_by_project_and_user(context, project_id, user_id):
                                                       project_id, user_id)
 
 
-def quota_destroy_all_by_share_type(context, share_type_id, project_id=None):
-    """Destroy all quotas associated with a given share type and project."""
-    return IMPL.quota_destroy_all_by_share_type(
-        context, share_type_id, project_id=project_id)
+def quota_destroy_all_by_project_and_share_type(context, project_id,
+                                                share_type_id):
+    """Destroy all quotas associated with a given project and user."""
+    return IMPL.quota_destroy_all_by_project_and_share_type(
+        context, project_id, share_type_id)
 
 
 def quota_destroy_all_by_project(context, project_id):
@@ -428,9 +429,10 @@ def share_access_get(context, access_id):
     return IMPL.share_access_get(context, access_id)
 
 
-def share_access_get_all_for_share(context, share_id):
+def share_access_get_all_for_share(context, share_id, filters=None):
     """Get all access rules for given share."""
-    return IMPL.share_access_get_all_for_share(context, share_id)
+    return IMPL.share_access_get_all_for_share(context, share_id,
+                                               filters=filters)
 
 
 def share_access_get_all_for_instance(context, instance_id, filters=None,
@@ -488,6 +490,17 @@ def share_instance_access_delete(context, mapping_id):
     """Deny access to share instance."""
     return IMPL.share_instance_access_delete(context, mapping_id)
 
+
+def share_access_metadata_update(context, access_id, metadata):
+    """Update metadata of share access rule."""
+    return IMPL.share_access_metadata_update(context, access_id, metadata)
+
+
+def share_access_metadata_delete(context, access_id, key):
+    """Delete metadata of share access rule."""
+    return IMPL.share_access_metadata_delete(context, access_id, key)
+
+
 ####################
 
 
