@@ -58,7 +58,7 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         retval = sched._format_filter_properties(
             fake_context, {}, request_spec)
 
-        self.assertTrue('replication_domain' in retval[0])
+        self.assertIn('replication_domain', retval[0])
 
     def test_create_share_no_hosts(self):
         # Ensure empty hosts/child_zones result in NoValidHosts exception.
@@ -150,9 +150,8 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             'share_instance_properties': {'project_id': 1, 'size': 1},
         }
 
-        weighed_host = sched._schedule_share(fake_context, request_spec, {})
-
-        self.assertIsNone(weighed_host)
+        self.assertRaises(exception.NoValidHost, sched._schedule_share,
+                          fake_context, request_spec, {})
         self.assertTrue(_mock_service_get_all_by_topic.called)
 
     @ddt.data(
@@ -203,37 +202,8 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             'share_properties': {'project_id': 1, 'size': 1},
             'share_instance_properties': {'project_id': 1, 'size': 1},
         }
-        weighed_host = sched._schedule_share(fake_context, request_spec, {})
-
-        self.assertIsNone(weighed_host)
-        self.assertTrue(_mock_service_get_all_by_topic.called)
-
-    @mock.patch('manila.db.service_get_all_by_topic')
-    def test_schedule_share_with_cg_pool_support(
-            self, _mock_service_get_all_by_topic):
-        sched = fakes.FakeFilterScheduler()
-        sched.host_manager = fakes.FakeHostManager()
-        fake_context = context.RequestContext('user', 'project',
-                                              is_admin=True)
-        fakes.mock_host_manager_db_calls(_mock_service_get_all_by_topic)
-        request_spec = {
-            'share_type': {
-                'name': 'NFS',
-                'extra_specs': {'consistency_group_support': 'pool'}
-            },
-            'share_properties': {'project_id': 1, 'size': 1},
-            'share_instance_properties': {'project_id': 1, 'size': 1},
-            'consistency_group': {
-                'id': 'fake-cg-id',
-                'host': 'host5#_pool0',
-            }
-        }
-
-        weighed_host = sched._schedule_share(fake_context, request_spec, {})
-
-        self.assertIsNotNone(weighed_host)
-        self.assertIsNotNone(weighed_host.obj)
-        self.assertEqual('host5#_pool0', weighed_host.obj.host)
+        self.assertRaises(exception.NoValidHost, sched._schedule_share,
+                          fake_context, request_spec, {})
         self.assertTrue(_mock_service_get_all_by_topic.called)
 
     def _setup_dedupe_fakes(self, extra_specs):
@@ -273,9 +243,8 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             {'capabilities:dedupe': capability})
         fakes.mock_host_manager_db_calls(_mock_service_get_all_by_topic)
 
-        weighed_host = sched._schedule_share(fake_context, request_spec, {})
-
-        self.assertIsNone(weighed_host)
+        self.assertRaises(exception.NoValidHost, sched._schedule_share,
+                          fake_context, request_spec, {})
         self.assertTrue(_mock_service_get_all_by_topic.called)
 
     def test_schedule_share_type_is_none(self):
@@ -303,9 +272,8 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             'share_instance_properties': {'availability_zone_id': "fake_az"},
         }
 
-        weighed_host = sched._schedule_share(fake_context, request_spec, {})
-
-        self.assertIsNone(weighed_host)
+        self.assertRaises(exception.NoValidHost, sched._schedule_share,
+                          fake_context, request_spec, {})
         self.assertTrue(_mock_service_get_all_by_topic.called)
 
     def test_max_attempts(self):
@@ -328,8 +296,9 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             'share_instance_properties': {},
         }
         filter_properties = {}
-        sched._schedule_share(self.context, request_spec,
-                              filter_properties=filter_properties)
+        self.assertRaises(exception.NoValidHost, sched._schedule_share,
+                          self.context, request_spec,
+                          filter_properties=filter_properties)
         # Should not have retry info in the populated filter properties.
         self.assertNotIn("retry", filter_properties)
 
@@ -343,8 +312,9 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             'share_instance_properties': {},
         }
         filter_properties = {}
-        sched._schedule_share(self.context, request_spec,
-                              filter_properties=filter_properties)
+        self.assertRaises(exception.NoValidHost, sched._schedule_share,
+                          self.context, request_spec,
+                          filter_properties=filter_properties)
         num_attempts = filter_properties['retry']['num_attempts']
         self.assertEqual(1, num_attempts)
 
@@ -359,8 +329,9 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         }
         retry = dict(num_attempts=1)
         filter_properties = dict(retry=retry)
-        sched._schedule_share(self.context, request_spec,
-                              filter_properties=filter_properties)
+        self.assertRaises(exception.NoValidHost, sched._schedule_share,
+                          self.context, request_spec,
+                          filter_properties=filter_properties)
         num_attempts = filter_properties['retry']['num_attempts']
         self.assertEqual(2, num_attempts)
 
@@ -401,41 +372,41 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
                          filter_properties['retry']['hosts'][0])
         self.assertEqual(1024, host_state.total_capacity_gb)
 
-    def test_schedule_create_consistency_group(self):
+    def test_schedule_create_share_group(self):
         # Ensure empty hosts/child_zones result in NoValidHosts exception.
         sched = fakes.FakeFilterScheduler()
         fake_context = context.RequestContext('user', 'project')
         fake_host = 'fake_host'
         request_spec = {'share_types': [{'id': 'NFS'}]}
-        self.mock_object(sched, "_get_best_host_for_consistency_group",
+        self.mock_object(sched, "_get_best_host_for_share_group",
                          mock.Mock(return_value=fake_host))
         fake_updated_group = mock.Mock()
-        self.mock_object(base, "cg_update_db", mock.Mock(
+        self.mock_object(base, "share_group_update_db", mock.Mock(
             return_value=fake_updated_group))
-        self.mock_object(sched.share_rpcapi, "create_consistency_group")
+        self.mock_object(sched.share_rpcapi, "create_share_group")
 
-        sched.schedule_create_consistency_group(fake_context, 'fake_id',
-                                                request_spec, {})
+        sched.schedule_create_share_group(fake_context, 'fake_id',
+                                          request_spec, {})
 
-        sched._get_best_host_for_consistency_group.assert_called_once_with(
+        sched._get_best_host_for_share_group.assert_called_once_with(
             fake_context, request_spec)
-        base.cg_update_db.assert_called_once_with(
+        base.share_group_update_db.assert_called_once_with(
             fake_context, 'fake_id', fake_host)
-        sched.share_rpcapi.create_consistency_group.assert_called_once_with(
+        sched.share_rpcapi.create_share_group.assert_called_once_with(
             fake_context, fake_updated_group, fake_host)
 
-    def test_create_cg_no_hosts(self):
+    def test_create_group_no_hosts(self):
         # Ensure empty hosts/child_zones result in NoValidHosts exception.
         sched = fakes.FakeFilterScheduler()
         fake_context = context.RequestContext('user', 'project')
         request_spec = {'share_types': [{'id': 'NFS'}]}
 
         self.assertRaises(exception.NoValidHost,
-                          sched.schedule_create_consistency_group,
+                          sched.schedule_create_share_group,
                           fake_context, 'fake_id', request_spec, {})
 
     @mock.patch('manila.db.service_get_all_by_topic')
-    def test_get_weighted_candidates_for_consistency_group(
+    def test_get_weighted_candidates_for_share_group(
             self, _mock_service_get_all_by_topic):
         sched = fakes.FakeFilterScheduler()
         sched.host_manager = fakes.FakeHostManager()
@@ -443,16 +414,16 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         fakes.mock_host_manager_db_calls(_mock_service_get_all_by_topic)
         request_spec = {'share_types': [{'name': 'NFS',
                                          'extra_specs': {
-                                             SNAPSHOT_SUPPORT: True,
+                                             SNAPSHOT_SUPPORT: 'True',
                                          }}]}
 
-        hosts = sched._get_weighted_candidates_cg(fake_context,
-                                                  request_spec)
+        hosts = sched._get_weighted_candidates_share_group(
+            fake_context, request_spec)
 
         self.assertTrue(hosts)
 
     @mock.patch('manila.db.service_get_all_by_topic')
-    def test_get_weighted_candidates_for_consistency_group_no_hosts(
+    def test_get_weighted_candidates_for_share_group_no_hosts(
             self, _mock_service_get_all_by_topic):
         sched = fakes.FakeFilterScheduler()
         sched.host_manager = fakes.FakeHostManager()
@@ -460,16 +431,16 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         fakes.mock_host_manager_db_calls(_mock_service_get_all_by_topic)
         request_spec = {'share_types': [{'name': 'NFS',
                                          'extra_specs': {
-                                             SNAPSHOT_SUPPORT: False
+                                             SNAPSHOT_SUPPORT: 'False',
                                          }}]}
 
-        hosts = sched._get_weighted_candidates_cg(fake_context,
-                                                  request_spec)
+        hosts = sched._get_weighted_candidates_share_group(
+            fake_context, request_spec)
 
         self.assertEqual([], hosts)
 
     @mock.patch('manila.db.service_get_all_by_topic')
-    def test_get_weighted_candidates_for_consistency_group_many_hosts(
+    def test_get_weighted_candidates_for_share_group_many_hosts(
             self, _mock_service_get_all_by_topic):
         sched = fakes.FakeFilterScheduler()
         sched.host_manager = fakes.FakeHostManager()
@@ -477,13 +448,13 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         fakes.mock_host_manager_db_calls(_mock_service_get_all_by_topic)
         request_spec = {'share_types': [{'name': 'NFS',
                                          'extra_specs': {
-                                             SNAPSHOT_SUPPORT: True
+                                             SNAPSHOT_SUPPORT: 'True',
                                          }}]}
 
-        hosts = sched._get_weighted_candidates_cg(fake_context,
-                                                  request_spec)
+        hosts = sched._get_weighted_candidates_share_group(
+            fake_context, request_spec)
 
-        self.assertEqual(2, len(hosts))
+        self.assertEqual(6, len(hosts))
 
     def _host_passes_filters_setup(self, mock_obj):
         sched = fakes.FakeFilterScheduler()
@@ -528,10 +499,15 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
 
     def test_schedule_create_replica_no_host(self):
         sched = fakes.FakeFilterScheduler()
-        request_spec = fakes.fake_replica_request_spec()
-
-        self.mock_object(self.driver_cls, '_schedule_share',
-                         mock.Mock(return_value=None))
+        request_spec = {
+            'share_type': {'name': 'fake_type'},
+            'share_properties': {'project_id': 1, 'size': 1},
+            'share_instance_properties': {'project_id': 1, 'size': 1},
+        }
+        self.mock_object(sched.host_manager, 'get_all_host_states_share',
+                         mock.Mock(return_value=[]))
+        self.mock_object(sched.host_manager, 'get_filtered_hosts',
+                         mock.Mock(return_value=(None, 'filter')))
 
         self.assertRaises(exception.NoValidHost,
                           sched.schedule_create_replica,
